// java wrapper for vtkProcess object
//

package vtk;
import vtk.*;

public class vtkProcess extends vtkObject
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void Execute_2();
  public void Execute()
    { Execute_2(); }

  private native long GetController_3();
  public vtkMultiProcessController GetController() {
    long temp = GetController_3();

    if (temp == 0) return null;
    return (vtkMultiProcessController)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetController_4(vtkMultiProcessController id0);
  public void SetController(vtkMultiProcessController id0)
    { SetController_4(id0); }

  private native int GetReturnValue_5();
  public int GetReturnValue()
    { return GetReturnValue_5(); }

  public vtkProcess() { super(); }

  public vtkProcess(long id) { super(id); }

}
